ControlState

Type Alias ControlState 

pub type ControlState<Q = usize> = State<ControlFlow<Q, Q>>;
A type alias for a State instance configured to leverage the ControlFlow enum as its inner type. This is a useful shortcut for representing a halt state.

Aliased Type

#[repr(transparent)]
pub struct ControlState<Q = usize>(pub ControlFlow<Q, Q>);

Tuple Fields

0: ControlFlow<Q, Q>